.. QEpy documentation master file

=================================
QEpy - Quantum ESPRESSO in Python
=================================

QEpy_ turns `Quantum ESPRESSO (QE) <https://www.quantum-espresso.org/>`_ into a Python DFT engine for nonstandard workflows.

Contributors and funding
========================

 - Main author: `Xuecheng Shao  <https://sites.rutgers.edu/prg/people/xuecheng-shao/>`_ (Rutgers)
 - Oliviero Andreussi (UNT), Davide Ceresoli (CNR, Italy), Matthew Truscott (UNT), Andrew Baczewski (Sandia), Quinn Campbell (Sandia), `Michele Pavanello <https://sasn.rutgers.edu/about-us/faculty-staff/michele-pavanello>`_ (Rutgers).
 - `The Quantum-Multiscale collaboration <http://www.quantum-multiscale.org/>`_.


Thanks to ...
=============
 - The Quantum ESPRESSO developers for the QE codebase
 - NSF for funding the Quantum-Multiscale collaboration

What's in this code?
====================
Small modifications to QE routines and a quick compilation with Python wrappers. QEpy_ is based on QE-6.5 and is kept up to date with the latest QE stable release.

.. toctree::
   :maxdepth: 2

   contact
   install
   tutorials/tutorials
   qepy/qepy
   development/development
   faq

.. _QEpy: https://gitlab.com/shaoxc/qepy
.. _Python: https://www.python.org
.. _DFTpy: http://dftpy.rutgers.edu
.. _PRG: https://sites.rutgers.edu/prg
